#!/bin/vtcl
# ---------------------------------------------------------------------
# Copyright 1994 by SCO, Inc.
# Permission to use, copy, modify, distribute, and sell this software
# and its documentation for any purpose is hereby granted without fee,
# provided that the above copyright notice appear in all copies and that
# both that copyright  notice  and  this  permission  notice  appear  in
# supporting documentation, and that the name  of  SCO  not  be used  in
# advertising or publicity pertaining  to distribution of  the  software
# without   specific,   written  prior   permission.    SCO   makes   no
# representations  about  the  suitability  of  this  software  for  any
# purpose.  It is provided "as is" without express or implied warranty.
# ---------------------------------------------------------------------

# Demo		: colorscale.tcl
# Description	: Example usage of the -xmArgs option for setting 
#		  a X/Motif resource, namely the background color in 
#		  a label widget.
# Comments	: use of Tcl commands: format, for_file, lrange,
#		  VtSetValues, VtGetValues		  
# Notes:	: This is _very_ primitive and can be greatly improved
#		  upon.
#  

# Close connection and exit Vtcl interpreter.
proc CloseCB { cbs } {
	VtClose; exit
}
###
### EDIT HERE - if your rgb text file resides elsewhere ####
###
set rgbFileName /usr/lib/X11/rgb.txt
###

# grab the human readable rgb colors from rgb.txt and 
# associated numerical values.  We'll ignore redundant
# info (e.g. Light Blue and lightblue).
#
proc GetColorNamesList {} {
	global colorArray dlog rgbFileName
	if { ! [file exists $rgbFileName] } {
		VtShow [VtErrorDialog $dlog.error \
			-message "Unable to locate:\n$rgbFileName\nYou must edit this script\nto add the correct filename." \
			-ok \
			-okCallback CloseCB \
			]
		VtMainLoop
	}
	for_file record $rgbFileName {

		# Get the name of the color.
		# Throw it away if it contains a space.
		#
		set name [lrange $record 3 end]
		if {[llength $name] > 1} {
			# move on to the next for_file loop...
			continue
		}
		lappend tmpList $name

		# grab the color triplets... and using the color name
		# as our array index, shove the triplet values into an
		# array element.
		#
		set colorArray($name) [format "%3s %3s %3s" \
			[lindex $record 0] \
			[lindex $record 1] \
			[lindex $record 2] \
			]
	}
	return $tmpList
}

# This routine just formats the 3 colors nicely...
#
proc GetColorValue {redV greenV blueV} {
	return [format "#%02x%02x%02x" $redV $greenV $blueV]
}

# Grab the selected color and update the label's background.
#
proc ChangeFormColorCB {type cbs} {
	global colorField colorLabel colorArray colorList \
		redScaleW blueScaleW greenScaleW

	switch -exact $type {
		"list" {
			set color [keylget cbs selectedItemList]
			VtSetValues $redScaleW \
				-value [lindex $colorArray($color) 0]
			VtSetValues $blueScaleW \
				-value [lindex $colorArray($color) 1]
			VtSetValues $greenScaleW \
				-value [lindex $colorArray($color) 2]
		}
		"scale" {
			set redValue [VtGetValues $redScaleW -value]
			set blueValue [VtGetValues $blueScaleW -value]
			set greenValue [VtGetValues $greenScaleW -value]
			set color [GetColorValue $redValue $greenValue \
				$blueValue]
			GetColorToNameMatch $redValue $blueValue $greenValue

		}
	}

	VtSetValues $colorField \
		-xmArgs "XmNbackground $color"

	VtSetValues $colorLabel \
		-label "Color:$color" \
}

# Loop through the array and match the color indexes to each
# stored triplets.
#
proc GetColorToNameMatch {red blue green} {
	global colorList colorArray
	VtLock
	set index 0
	foreach name [array names colorArray] {
		set formatedList [format "%3s %3s %3s" $red $green $blue]
		if {$formatedList == $colorArray($name)} {
			VtListSelectItem $colorList \
				-item $name 
			set nameList [VtListGetItem $colorList -all]
			set index [lsearch $nameList $name]
			VtSetValues $colorList -topItemPosition $index
			VtUnLock
			return
		}
		incr index
	}
	VtUnLock
}

proc PostCharmInfo {parent} {
	VtShow [VtInformationDialog $parent.ibox \
		-message "Because there is no color support in \n \
			  character motif, this demo will not be \n \
			  useful to you." \
		-ok \
		-okCallback CloseCB \
		]
	VtMainLoop
}

set colorArray(dummy) {}
#
# Open connection with Visual Tcl display engine
#
set app [VtOpen colorScale]

if { [VtInfo -charm] } {
	PostCharmInfo $app
}

set dlog [VtFormDialog $app.dialog\
	-title "Demo: color scale" \
	-ok \
	-okCallback CloseCB \
	]

set rowCol [VtRowColumn $dlog.rowCol \
	]
set redScaleW [VtScale $rowCol.red \
	-title "Red" \
	-min 0 \
	-max 255 \
	-callback {ChangeFormColorCB scale} \
	-value 0 \
	]
set greenScaleW [VtScale $rowCol.green \
	-title "Green" \
	-min 0 \
	-max 255 \
	-callback {ChangeFormColorCB scale} \
	-value 0 \
	]
set blueScaleW [VtScale $rowCol.blue \
	-title "Blue" \
	-min 0 \
	-max 255 \
	-callback {ChangeFormColorCB scale} \
	-value 0 \
	]

# we'll put our color field (which is a label widget) inside
# a frame to give it a nice, raised relief look.
#
set frame [VtFrame $dlog.frame \
	-leftSide $rowCol \
	-leftOffset 15 \
	-topSide FORM \
	-alignBottom $rowCol \
	-shadowType OUT \
	]
set colorField [VtLabel $frame.colorField \
	-label "          " \
	]

# Initial color value
#
set value [GetColorValue 0 0 0]

# Show the user the actual value getting passed to XmNbackground.
#
set colorLabel [VtLabel $dlog.colorLabel \
	-label "Color: $value" \
	-topSide $rowCol \
	-leftSide FORM \
	-bottomSide FORM \
	]

set colorList [VtList $dlog.colorList \
	-itemList [GetColorNamesList] \
	-leftSide $frame \
	-leftOffset 15 \
	-alignTop $frame \
	-alignBottom $frame \
	-rightSide FORM \
	-callback {ChangeFormColorCB list} \
	]
VtShow $dlog
VtMainLoop
